%global ppp_ver %(rpm -q --queryformat "%{VERSION}" ppp)

Summary: 	An IP address pool manager
Name: 		ippool
Version: 	1.3
Release: 	%mkrel 18
License: 	GPLv2+
Group: 		System/Servers
URL: 		http://www.openl2tp.org/
Source0: 	https://sourceforge.net/projects/openl2tp/files/ippool/%{version}/%{name}-%{version}.tar.gz
Source1:	ippool.service
Source2:	ippool-tmpfiles.conf
Patch0: 	ippool-rm_unused.patch
Patch2:		ippool-1.3-dso.patch
# https://sourceforge.net/p/openl2tp/patches/19/
Patch3:		ippool-1.3.pppd.patch
# From pld
Patch4:		ippool-tirpc.patch
#
BuildRequires:	ppp-devel >= 2.4.4
BuildRequires:	readline-devel
BuildRequires:	glibc-devel
BuildRequires:	flex
BuildRequires:	bison
BuildRequires:	rpcgen
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	pkgconfig(libtirpc)
Requires:	ppp = %{ppp_ver}
Requires:       readline
Requires:        rpcbind
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper
Requires(preun): rpm-helper

%description
IpPool is an IP address pool manager.

IpPool is implemented as a separate server daemon to allow any application
to use its address pools. This makes it possible to define address
pools that are shared by PPP, L2TP, PPTP etc. It may be useful in some VPN
server setups.

IpPool comes with a command line management application, ippoolconfig
to manage and query address pool status. A pppd plugin is supplied which
allows pppd to request IP addresses from ippoold.

%prep
%setup -q
%autopatch -p1

%build
%__make \
  CPPFLAGS="%{optflags} -Wno-error=unused-but-set-variable -I%{_includedir}/tirpc" \
  CFLAGS="%{optflags} -Wno-error=unused-but-set-variable -Iusl -Icli -I/usr/include/pppd/ -I/usr/include/readline/ -I%{_includedir}/tirpc -I.. -DUINT_MAX=32768"

%install
%make_install \
  SYS_LIBDIR=%{_libdir} \
  PPPD_VERSION=%{ppp_ver} \
  PPPD_LIBDIR=%{_libdir}/pppd/%{ppp_ver}

%{__install} -D -p -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/ippool.service
%{__install} -D -p -m 0644 etc/sysconfig/ippoold %{buildroot}%{_sysconfdir}/sysconfig/ippoold
%{__install} -D -p -m 0644 %{SOURCE2} %{buildroot}%{_tmpfilesdir}/%{name}.conf

%post
%_tmpfilescreate %{name}
%_post_service %{name}

%preun
%_preun_service %{name}


%files
%doc README
%{_tmpfilesdir}/%{name}.conf
%dir %{_libdir}/ippool
%{_bindir}/ippoolconfig
%{_sbindir}/ippoold
%{_libdir}/ippool/ippool_rpc.x
%{_libdir}/pppd/%{ppp_ver}/ippool.so
%{_mandir}/man1/ippoolconfig.1.*
%{_mandir}/man4/ippool_rpc.4.*
%{_mandir}/man8/ippoold.8.*
%{_unitdir}/ippool.service
%config %{_sysconfdir}/sysconfig/ippoold


%changelog
* Fri Dec 04 2020 ghibo <ghibo> 1.3-18.mga8
+ Revision: 1652674
- Add patch from PLD to fix building errors
+ tv <tv>
- use libtirpc
- BR rpcgen (fix build with glibc-2.32)

* Fri Oct 16 2020 luigiwalser <luigiwalser> 1.3-17.mga8
+ Revision: 1636389
- rebuild for ppp 2.4.8

* Tue Feb 18 2020 umeabot <umeabot> 1.3-16.mga8
+ Revision: 1542175
- Mageia 8 Mass Rebuild

* Sat Jan 04 2020 luigiwalser <luigiwalser> 1.3-15.mga8
+ Revision: 1475970
- rebuild for readline

* Sun Sep 23 2018 umeabot <umeabot> 1.3-14.mga7
+ Revision: 1298310
- Mageia 7 Mass Rebuild

* Fri Jun 22 2018 wally <wally> 1.3-13.mga7
+ Revision: 1238783
- drop unneeded ppp version patch
- add pppd plugin crash fix patch
- define SYS_LIBDIR to fix build on aarch64
+ kekepower <kekepower>
- Use __make

* Tue Jan 02 2018 wally <wally> 1.3-12.mga7
+ Revision: 1189443
- rebuild for new readline
- update license

* Tue Oct 03 2017 wally <wally> 1.3-11.mga7
+ Revision: 1168026
- add strict version requires for ppp

* Thu Feb 11 2016 umeabot <umeabot> 1.3-10.mga6
+ Revision: 954449
- Mageia 6 Mass Rebuild

* Sun Aug 30 2015 cjw <cjw> 1.3-9.mga6
+ Revision: 871138
- patch2: fix linking of the loadable module

* Wed Oct 15 2014 umeabot <umeabot> 1.3-8.mga5
+ Revision: 739898
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.3-7.mga5
+ Revision: 680541
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 1.3-6.mga4
+ Revision: 522639
- Mageia 4 Mass Rebuild

* Sun Mar 24 2013 colin <colin> 1.3-5.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)
+ dlucio <dlucio>
- P1 to fix PPP path

* Mon Mar 04 2013 dlucio <dlucio> 1.3-3.mga3
+ Revision: 401367
- More fixes

* Mon Mar 04 2013 dlucio <dlucio> 1.3-2.mga3
+ Revision: 401358
- systemd config

* Mon Mar 04 2013 dlucio <dlucio> 1.3-1.mga3
+ Revision: 401341
- BR fixes
- Let us Mageia it
- imported package ippool


* Wed Apr 09 2008 James Chapman - 1.3

- Fix version number. Versions 1.1 and 1.2 advertised themselves as 1.0.

* Fri Mar 21 2008 James Chapman - 1.2

- Change to Debian package control file.

* Sun Feb 24 2008 James Chapman - 1.1

- Build with new USL list management code which includes memory
  barriers. This prevents gcc function order optimisations from
  causing problems.
  
- Enable compiler optimisation.

* Sun Feb 10 2008 James Chapman - 1.0

- Initial build.

